==> bce-java-sdk-0.10.157-sources.jar: com/baidubce/services/blb/model/BlbInstance.java <==
/*
 * Copyright (c) 2014 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.blb.model;

/**
 * The blb info modal.
 */
public class BlbInstance {

    /**
     * the short id of the blb.
     */
    private String blbId;
    /**
     * the status of the blb.
     */
    private String status;
    /**
     * the name of the blb.
     */
    private String name;
    /**
     * the description of the blb.
     */
    private String desc;
    /**
     * the address of the blb.
     */
    private String address;
    /**
     * the short vpc id of the blb.
     */
    private String vpcId;
    /**
     * the short subnet id of the blb.
     */
    private String subnetId;
    /**
     * the public ip of the blb.
     */
    private String publicIp;

    public String getBlbId() {
        return blbId;
    }

    public void setBlbId(String blbId) {
        this.blbId = blbId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getPublicIp() {
        return publicIp;
    }

    public void setPublicIp(String publicIp) {
        this.publicIp = publicIp;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getVpcId() {
        return vpcId;
    }

    public void setVpcId(String vpcId) {
        this.vpcId = vpcId;
    }

    public String getSubnetId() {
        return subnetId;
    }

    public void setSubnetId(String subnetId) {
        this.subnetId = subnetId;
    }

}

==> bce-java-sdk-0.10.315-sources.jar: com/baidubce/services/blb/model/BlbInstance.java <==
/*
 * Copyright (c) 2014 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.blb.model;

import com.baidubce.model.AbstractBceResponse;

/**
 * The blb info modal.
 */
public class BlbInstance extends AbstractBceResponse {

    /**
     * the short id of the blb.
     */
    private String blbId;
    /**
     * the status of the blb.
     */
    private String status;
    /**
     * the name of the blb.
     */
    private String name;
    /**
     * the description of the blb.
     */
    private String desc;
    /**
     * the address of the blb.
     */
    private String address;
    /**
     * the short vpc id of the blb.
     */
    private String vpcId;
    /**
     * the short subnet id of the blb.
     */
    private String subnetId;
    /**
     * the public ip of the blb.
     */
    private String publicIp;

    public String getBlbId() {
        return blbId;
    }

    public void setBlbId(String blbId) {
        this.blbId = blbId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getPublicIp() {
        return publicIp;
    }

    public void setPublicIp(String publicIp) {
        this.publicIp = publicIp;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getVpcId() {
        return vpcId;
    }

    public void setVpcId(String vpcId) {
        this.vpcId = vpcId;
    }

    public String getSubnetId() {
        return subnetId;
    }

    public void setSubnetId(String subnetId) {
        this.subnetId = subnetId;
    }

    @Override
    public String toString() {
        return "BlbInstance{" +
                "blbId='" + blbId + '\'' +
                ", status='" + status + '\'' +
                ", name='" + name + '\'' +
                ", desc='" + desc + '\'' +
                ", address='" + address + '\'' +
                ", vpcId='" + vpcId + '\'' +
                ", subnetId='" + subnetId + '\'' +
                ", publicIp='" + publicIp + '\'' +
                '}';
    }
}
